@@ -62,7 +62,7 @@ class WEASEL(BaseClassifier):
     binning_strategy: {"equi-depth", "equi-width", "information-gain"},
     default="information-gain"
         The binning method used to derive the breakpoints.
-    window_inc: int, default=4
+    window_inc: int, default=2
         WEASEL create a BoP model for each window sizes. This is the
         increment used to determine the next window size.
     p_threshold:  int, default=0.05 (disabled by default)
@@ -110,6 +110,7 @@ class WEASEL(BaseClassifier):
 
     _tags = {
         "capability:multithreading": True,
+        "classifier_type": "dictionary",
     }
 
     def __init__(
@@ -279,7 +280,7 @@ class WEASEL(BaseClassifier):
 
         return self
 
-    def _predict(self, X):
+    def _predict(self, X) -> np.ndarray:
         """Predict class values of n instances in X.
 
         Parameters
@@ -295,7 +296,7 @@ class WEASEL(BaseClassifier):
         bag = self._transform_words(X)
         return self.clf.predict(bag)
 
-    def _predict_proba(self, X):
+    def _predict_proba(self, X) -> np.ndarray:
         """Predict class probabilities for n instances in X.
 
         Parameters
@@ -342,3 +343,18 @@ class WEASEL(BaseClassifier):
     @njit("int64(int64,int64,int64)", fastmath=True, cache=True)
     def _shift_left(key, highest_bit, window_size):
         return (key << highest_bit) | window_size
+
+    @classmethod
+    def get_test_params(cls):
+        """Return testing parameter settings for the estimator.
+
+        Returns
+        -------
+        params : dict or list of dict, default={}
+            Parameters to create testing instances of the class.
+            Each dict are parameters to construct an "interesting" test instance, i.e.,
+            `MyClass(**params)` or `MyClass(**params[i])` creates a valid test instance.
+            `create_test_instance` uses the first (or only) dictionary in `params`.
+        """
+        params = {"window_inc": 5}
+        return params
