@@ -53,9 +53,7 @@ class MiniRocket(_PanelToTabularTransformer):
         self.max_dilations_per_kernel = max_dilations_per_kernel
 
         self.n_jobs = n_jobs
-        self.random_state = (
-            np.int32(random_state) if isinstance(random_state, int) else None
-        )
+        self.random_state = random_state
         super(MiniRocket, self).__init__()
 
     def fit(self, X, y=None):
@@ -71,6 +69,11 @@ class MiniRocket(_PanelToTabularTransformer):
         self
         """
         X = check_X(X, enforce_univariate=True, coerce_to_numpy=True)
+
+        random_state = (
+            np.int32(self.random_state) if isinstance(self.random_state, int) else None
+        )
+
         X = X[:, 0, :].astype(np.float32)
         _, n_timepoints = X.shape
         if n_timepoints < 9:
@@ -81,7 +84,7 @@ class MiniRocket(_PanelToTabularTransformer):
                 )
             )
         self.parameters = _fit(
-            X, self.num_kernels, self.max_dilations_per_kernel, self.random_state
+            X, self.num_kernels, self.max_dilations_per_kernel, random_state
         )
         self._is_fitted = True
         return self
