@@ -11,14 +11,13 @@ from sktime.datatypes._panel._convert import (
     _get_column_names,
     _get_time_index,
 )
-from sktime.transformations.base import _PanelToPanelTransformer
+from sktime.transformations.base import BaseTransformer
 from sktime.utils.validation import check_window_length
 from sktime.utils.validation.panel import check_X
 
 
-class IntervalSegmenter(_PanelToPanelTransformer):
-    """
-    Interval segmentation transformer.
+class IntervalSegmenter(BaseTransformer):
+    """Interval segmentation transformer.
 
     Parameters
     ----------
@@ -31,7 +30,17 @@ class IntervalSegmenter(_PanelToPanelTransformer):
         and the second column giving end points of intervals
     """
 
-    _tags = {"univariate-only": True}
+    _tags = {
+        "univariate-only": True,
+        "scitype:transform-input": "Series",
+        # what is the scitype of X: Series, or Panel
+        "scitype:transform-output": "Series",
+        # what scitype is returned: Primitives, Series, Panel
+        "scitype:instancewise": True,  # is this an instance-wise transform?
+        "X_inner_mtype": "nested_univ",  # which mtypes do _fit/_predict support for X?
+        "y_inner_mtype": "None",  # which mtypes do _fit/_predict support for X?
+        "fit_is_empty": False,  # is fit empty and can be skipped? Yes = True
+    }
 
     def __init__(self, intervals=10):
         self.intervals = intervals
@@ -39,16 +48,17 @@ class IntervalSegmenter(_PanelToPanelTransformer):
         self.input_shape_ = ()
         super(IntervalSegmenter, self).__init__()
 
-    def fit(self, X, y=None):
+    def _fit(self, X, y=None):
         """
         Fit transformer, generating random interval indices.
 
         Parameters
         ----------
-        X : pandas DataFrame of shape [n_samples, n_features]
-            Input data
-        y : pandas Series, shape (n_samples, ...), optional
-            Targets for supervised learning.
+        X : nested pandas DataFrame of shape [n_instances, n_features]
+            each cell of X must contain pandas.Series
+            Data to fit transform to
+        y : ignored argument for interface compatibility
+            Additional data, e.g., labels for transformation
 
         Returns
         -------
@@ -68,6 +78,7 @@ class IntervalSegmenter(_PanelToPanelTransformer):
             if not self.intervals <= n_timepoints // 2:
                 raise ValueError(
                     "The number of intervals must be half the number of time points"
+                    " or less"
                 )
             self.intervals_ = np.array_split(self._time_index, self.intervals)
 
@@ -76,10 +87,9 @@ class IntervalSegmenter(_PanelToPanelTransformer):
                 f"Intervals must be either an integer, an array with "
                 f"start and end points, but found: {self.intervals}"
             )
-        self._is_fitted = True
         return self
 
-    def transform(self, X, y=None):
+    def _transform(self, X, y=None):
         """Transform input series.
 
         Transform X, segments time-series in each column into random
@@ -88,8 +98,10 @@ class IntervalSegmenter(_PanelToPanelTransformer):
 
         Parameters
         ----------
-        X : nested pandas DataFrame of shape [n_samples, n_features]
-            Nested dataframe with time-series in cells.
+        X : nested pandas DataFrame of shape [n_instances, n_features]
+            each cell of X must contain pandas.Series
+            Data to be transformed
+        y : ignored argument for interface compatibility
 
         Returns
         -------
@@ -97,9 +109,6 @@ class IntervalSegmenter(_PanelToPanelTransformer):
           Transformed pandas DataFrame with same number of rows and one
           column for each generated interval.
         """
-        # Check inputs.
-        self.check_is_fitted()
-
         # Tabularise assuming series
         # have equal indexes in any given column
         X = check_X(X, enforce_univariate=True, coerce_to_numpy=True)
@@ -123,6 +132,22 @@ class IntervalSegmenter(_PanelToPanelTransformer):
         Xt.columns = new_column_names
         return Xt
 
+    @classmethod
+    def get_test_params(cls):
+        """Return testing parameter settings for the estimator.
+
+        Returns
+        -------
+        params : dict or list of dict, default = {}
+            Parameters to create testing instances of the class
+            Each dict are parameters to construct an "interesting" test instance, i.e.,
+            `MyClass(**params)` or `MyClass(**params[i])` creates a valid test instance.
+            `create_test_instance` uses the first (or only) dictionary in `params`
+        """
+        # small number of intervals for testing
+        params = {"intervals": 2}
+        return params
+
 
 class RandomIntervalSegmenter(IntervalSegmenter):
     """Random interval segmenter transformer.
@@ -156,6 +181,12 @@ class RandomIntervalSegmenter(IntervalSegmenter):
         by `np.random`.
     """
 
+    _tags = {
+        "X_inner_mtype": "nested_univ",  # which mtypes do _fit/_predict support for X?
+        "y_inner_mtype": "pd_Series_Table",
+        # which mtypes do _fit/_predict support for y?
+    }
+
     def __init__(
         self, n_intervals="sqrt", min_length=None, max_length=None, random_state=None
     ):
@@ -165,16 +196,16 @@ class RandomIntervalSegmenter(IntervalSegmenter):
         self.random_state = random_state
         super(RandomIntervalSegmenter, self).__init__()
 
-    def fit(self, X, y=None):
-        """
-        Fit transformer, generating random interval indices.
+    def _fit(self, X, y=None):
+        """Fit transformer, generating random interval indices.
 
         Parameters
         ----------
-        X : pandas DataFrame of shape [n_samples, n_features]
-            Input data
-        y : pandas Series, shape (n_samples, ...), optional
-            Targets for supervised learning.
+        X : nested pandas DataFrame of shape [n_instances, n_features]
+            each cell of X must contain pandas.Series
+            Data to fit transform to
+        y : any container with method shape, optional, default=None
+            y.shape[0] determines n_timepoints, 1 if None
 
         Returns
         -------
@@ -200,7 +231,6 @@ class RandomIntervalSegmenter(IntervalSegmenter):
             if not min_length < self.max_length:
                 raise ValueError("`max_length` must be bigger than `min_length`.")
 
-        X = check_X(X, enforce_univariate=True)
         self.input_shape_ = X.shape
 
         # Retrieve time-series indexes from each column.
@@ -228,9 +258,24 @@ class RandomIntervalSegmenter(IntervalSegmenter):
                 max_length=self.max_length,
                 random_state=self.random_state,
             )
-        self._is_fitted = True
         return self
 
+    @classmethod
+    def get_test_params(cls):
+        """Return testing parameter settings for the estimator.
+
+        Returns
+        -------
+        params : dict or list of dict, default = {}
+            Parameters to create testing instances of the class
+            Each dict are parameters to construct an "interesting" test instance, i.e.,
+            `MyClass(**params)` or `MyClass(**params[i])` creates a valid test instance.
+            `create_test_instance` uses the first (or only) dictionary in `params`
+        """
+        # we need to override this, or it inherits from IntervalSegmenter
+        #   but this estimator does not have an "intervals" parameter
+        return {}
+
 
 def _rand_intervals_rand_n(x, random_state=None):
     """Sample a random number of intervals.
@@ -299,7 +344,7 @@ def _rand_intervals_fixed_n(
     return np.column_stack([starts, ends])
 
 
-class SlidingWindowSegmenter(_PanelToPanelTransformer):
+class SlidingWindowSegmenter(BaseTransformer):
     """Sliding window segmenter transformer.
 
     This class is to transform a univariate series into a
@@ -332,26 +377,37 @@ class SlidingWindowSegmenter(_PanelToPanelTransformer):
     Proposed in the ShapeDTW algorithm.
     """
 
-    _tags = {"univariate-only": True, "fit-in-transform": True}
+    _tags = {
+        "univariate-only": True,
+        "fit_is_empty": True,
+        "scitype:transform-input": "Series",
+        # what is the scitype of X: Series, or Panel
+        "scitype:transform-output": "Series",
+        # what scitype is returned: Primitives, Series, Panel
+        "scitype:instancewise": False,  # is this an instance-wise transform?
+        "X_inner_mtype": "nested_univ",  # which mtypes do _fit/_predict support for X?
+        "y_inner_mtype": "None",  # which mtypes do _fit/_predict support for y?
+    }
 
     def __init__(self, window_length=5):
         self.window_length = window_length
         super(SlidingWindowSegmenter, self).__init__()
 
-    def transform(self, X, y=None):
+    def _transform(self, X, y=None):
         """Transform time series.
 
         Parameters
         ----------
-        X : a pandas dataframe of shape = [n_instances, 1]
-            The training input samples.
+        X : nested pandas DataFrame of shape [n_instances, n_features]
+            each cell of X must contain pandas.Series
+            Data to be transformed
+        y : ignored argument for interface compatibility
 
         Returns
         -------
         dims: a pandas data frame of shape = [n_instances, n_timepoints]
         """
         # get the number of attributes and instances
-        self.check_is_fitted()
         X = check_X(X, enforce_univariate=True, coerce_to_numpy=True)
         X = X.squeeze(1)
 
