@@ -61,7 +61,7 @@ class HampelFilter(BaseTransformer):
         "X_inner_mtype": ["pd.DataFrame", "pd.Series"],
         # which mtypes do _fit/_predict support for X?
         "y_inner_mtype": "None",  # which mtypes do _fit/_predict support for y?
-        "fit-in-transform": True,
+        "fit_is_empty": True,
         "handles-missing-data": True,
         "skip-inverse-transform": True,
         "univariate-only": False,
